Image Processing with Hyperdimensional Computing
This module implements HDC-based image processing algorithms including image encoding, pattern recognition, feature detection, and sequence processing for computer vision applications.
Structs
- ImageHDC
Encoder - HDC-based image encoder
Functions
- create_
patches - Create patches from image with specified stride and size
- encode_
semantic_ concepts - Semantic encoding of concepts
- hdc_
compositional_ reasoning - HDC-based Compositional Reasoning
- hdc_
feature_ detection - HDC-based Feature Detection
- hdc_
image_ classification - HDC-based Image Classification
- hdc_
pattern_ matching - HDC-based Pattern Matching
- hdc_
pattern_ recognition - HDC-based pattern recognition
- hdc_
sequence_ processing - HDC-based Sequence Processing
- multiscale_
encoding - Multi-scale image encoding