pub struct AdaptiveStreamProcessor<T> { /* private fields */ }Expand description
Advanced adaptive streaming processor with dynamic load balancing
This processor automatically adjusts chunk sizes based on available memory and processing performance, providing optimal throughput for different types of operations and hardware configurations.
Implementations
Sourceimpl<T> AdaptiveStreamProcessor<T>
impl<T> AdaptiveStreamProcessor<T>
pub fn new(_baseconfig: StreamConfig) -> Self
Sourcepub fn process_adaptive<D, Op>(
&mut self,
input: &ArrayView<'_, T, D>,
op: Op,
) -> NdimageResult<Array<T, D>>
pub fn process_adaptive<D, Op>( &mut self, input: &ArrayView<'_, T, D>, op: Op, ) -> NdimageResult<Array<T, D>>
Process large array with adaptive chunking strategy
Sourcepub fn process_gpu_accelerated<D, Op>(
&mut self,
input: &ArrayView<'_, T, D>,
op: Op,
) -> NdimageResult<Array<T, D>>
pub fn process_gpu_accelerated<D, Op>( &mut self, input: &ArrayView<'_, T, D>, op: Op, ) -> NdimageResult<Array<T, D>>
Process with GPU-accelerated chunking when available