Module image_processing

Module image_processing 

Image Processing with Hyperdimensional Computing

This module implements HDC-based image processing algorithms including image encoding, pattern recognition, feature detection, and sequence processing for computer vision applications.

Structs

ImageHDCEncoder
HDC-based image encoder

Functions

create_patches
Create patches from image with specified stride and size
encode_semantic_concepts
Semantic encoding of concepts
hdc_compositional_reasoning
HDC-based Compositional Reasoning
hdc_feature_detection
HDC-based Feature Detection
hdc_image_classification
HDC-based Image Classification
hdc_pattern_matching
HDC-based Pattern Matching
hdc_pattern_recognition
HDC-based pattern recognition
hdc_sequence_processing
HDC-based Sequence Processing
multiscale_encoding
Multi-scale image encoding